import requests

class Hercai:
    def __init__(self, api_key=""):
        if api_key is None or api_key == "" or not isinstance(api_key, str):
            self.api_key = ""
        else:
            self.api_key = api_key
 
    def question(self, model="v3", content=None):
        if model not in ["v3", "gemini", "v3-32k", "turbo", "turbo-16k"]:
            model = "v3"
        if not content:
            raise ValueError("Please specify a question!")

        try:
            api = requests.get(
                f"https://hercai.onrender.com/{model}/hercai?question=" + requests.utils.quote(content),
                headers={"content-type": "application/json","Authorization": self.api_key},
            )
            return api.json()
        except Exception as err:
            raise ValueError("Error: " + str(err))
  
    def draw_image(self, model="v3", prompt=None, negative_prompt=None):
        if model not in ["v1", "v2", "v2-beta", "v3", "lexica", "prodia", "simurg", "animefy", "raava", "shonin"]:
            model = "prodia"
        if not prompt:
            raise ValueError("Please specify a prompt!")
        if not negative_prompt:
            negative_prompt = ""

        try:
            api = requests.get(
                f"https://hercai.onrender.com/{model}/text2image?prompt="
                + requests.utils.quote(prompt)
                + "&negative_prompt="
                + requests.utils.quote(negative_prompt),
                headers={"content-type": "application/json","Authorization": self.api_key},
                data={"key": self.api_key},
            )
            return api.json()
        except Exception as err:
            raise ValueError("Error: " + str(err))



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="hercai",
    version="3.0.1",
    author="fivesobes",
    description="A powerful Python Package for interacting with the Herc.ai API.",
    fullname="hercai",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Bes-js/Hercai.py",
    packages=find_packages(),
    license="GPL-3.0",
    keywords=["ai","chatbot","chatgpt","gpt","API","web","arc","smart","smartestchatbot","api","dalle","dall-e","text2image","texttoimage","text2img","texttoimg","image","image-generator","midjourney","diffusion","dall-e2","ai-images","ai-images-generator","gpt",
    "discord","chat","chatbot","chatgpt4","chatgpt-4","openai","open-ai","hercai","herc","herc.ai","smartest","bot","robot","axios",
    "canvafy","streamed-chatgpt-api","dart-openai-sdk","completions","cli","bin","command","console","cmd","bing","bing-chat","openaiapi","open.ai","openai-api","luppux","fivesobes","gemini","gemini-api","gemini-pro","google","five","bes","discord-ai","discordai","free","lodash","react","next","chalk","free","lodash","stable","anime","bes","fivesobes","five"],
    install_requires=["requests"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Internet :: WWW/HTTP :: Indexing/Search",
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    requires=["requests"],
    zip=False,
)
